Module: ActionDispatch::Routing
- Defined in:
- lib/secured.rb
Overview
This is in a pull request to the full devise gem, we may be able to remove it in the future
Defined Under Namespace
Classes: Mapper, SslConstraint
This is in a pull request to the full devise gem, we may be able to remove it in the future
Classes: Mapper, SslConstraint